@@ -7,7 +7,7 @@
 ##======================================================================
 
 package DDC::Concordance;
-require 5.10.0;  ##-- for // operator
+#require 5.10.0;  ##-- for // operator : dependency REMOVED for DDC::Concordance v0.22
 use DDC::HitList;
 use DDC::Hit;
 use DDC::Client;
@@ -21,7 +21,7 @@ use strict;
 
 ##======================================================================
 ## Globals
-our $VERSION = '0.21'; ##-- for ddc >= v2.0.21; fixes for ddc >= 2.0.38
+our $VERSION = '0.22'; ##-- for ddc >= v2.0.21; fixes for ddc >= 2.0.38
 our @ISA = qw();
 
 
