@@ -74,14 +74,14 @@ sub toString {
 
   my $xlen = $fmt->{width} || 2**31;
   my $hnum = $hits->{start};
-  my $useMatchIds = $fmt->{useMatchIds} // (grep {$_>0 && $_!=1} map {$_->{hl_}} map {@{$_->{ctx_}[1]}} @{$hits->{hits_}});
+  my $useMatchIds = defined($fmt->{useMatchIds}) ? $fmt->{useMatchIds} : (grep {$_>0 && $_!=1} map {$_->{hl_}} map {@{$_->{ctx_}[1]}} @{$hits->{hits_}});
 
   my (@hits);
   foreach my $hit (@{$hits->{hits_}}) {
     ##-- hit key: number + file basename + page
     my $f = basename($hit->{meta_}{file_});
     $f =~ s/\..*$//;
-    my $p     = ($hit->{meta_}{page_}//0);
+    my $p     = defined($hit->{meta_}{page_}) ? $hit->{meta_}{page_} : 0;
     my $pagei = (grep {$hit->{meta_}{indices_}[$_] eq 'page'} (0..$#{$hit->{meta_}{indices_}}))[0];
     my $targetMatchId = $useMatchIds ? (sort {$a<=>$b} grep {$_} map {$_->{hl_}} @{$hit->{ctx_}[1]})[0] : undef;
 
